pub fn render(policy: &Policy) -> Result<RenderedOutput>Expand description
Render the AGENTS.md output for the given policy.
Errors
Returns Error::Render if the template fails to compile or render.
pub fn render(policy: &Policy) -> Result<RenderedOutput>Render the AGENTS.md output for the given policy.
Returns Error::Render if the template fails to compile or render.