pub enum TargetId {
AgentsMd,
ClaudeMd,
CursorRules,
GeminiMd,
CopilotInstructions,
Clinerules,
WindsurfRules,
CopilotInstructionsScoped,
JunieGuidelines,
}Expand description
A stable identifier for each supported output target.
Variants
AgentsMd
ClaudeMd
CursorRules
GeminiMd
CopilotInstructions
Clinerules
WindsurfRules
CopilotInstructionsScoped
JunieGuidelines
Implementations
Sourceimpl TargetId
impl TargetId
Sourcepub fn from_id(id: &str) -> Option<Self>
pub fn from_id(id: &str) -> Option<Self>
Parse a target ID from its YAML string representation.
Sourcepub fn primary_path(self) -> &'static str
pub fn primary_path(self) -> &'static str
Primary output path produced by this target.
Sourcepub fn generated_glob(self) -> &'static str
pub fn generated_glob(self) -> &'static str
Glob pattern(s) that cover all output files produced by this target.
Used to auto-populate paths.generated in the normalized model so that
users do not need to list output files in both outputs: and
paths.generated:.